==> testdisk_6.4.1.orig.tar.gz: testdisk-6.4.1/src/file_sit.c <==
/*

    File: file_sit.c

    Copyright (C) 2005 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 59
    Temple Place - Suite 330, Boston MA 02111-1307, USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include "types.h"
#include "photorec.h"

static const char* header_check_sit(const unsigned char *buffer, const unsigned int buffer_size,  const unsigned int safe_header_only, t_file_recovery *file_recovery);

const t_file_hint file_hint_sit= {
  .extension="sit",
  .description="Mikron",
  .min_header_distance=0,
  .min_filesize=0,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_sit,
  .data_check=NULL,
  .file_check=NULL
};

static const char* header_check_sit(const unsigned char *buffer, const unsigned int buffer_size,  const unsigned int safe_header_only, t_file_recovery *file_recovery)
{
  const unsigned char header_sit[14]  = { '7','1','0','0',' ','3','.','3','D',' ','7','1','0','0'};
  if(memcmp(buffer,header_sit,sizeof(header_sit))==0)
    return file_hint_sit.extension;
  return NULL;
}

==> testdisk_6.5.orig.tar.gz: testdisk-6.5.orig/src/file_sit.c <==
/*

    File: file_sit.c

    Copyright (C) 2005 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "photorec.h"

static const char* header_check_sit(const unsigned char *buffer, const unsigned int buffer_size,  const unsigned int safe_header_only, t_file_recovery *file_recovery);

const t_file_hint file_hint_sit= {
  .extension="sit",
  .description="Mikron",
  .min_header_distance=0,
  .min_filesize=0,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_sit,
  .data_check=NULL,
  .file_check=NULL
};

static const char* header_check_sit(const unsigned char *buffer, const unsigned int buffer_size,  const unsigned int safe_header_only, t_file_recovery *file_recovery)
{
  const unsigned char header_sit[14]  = { '7','1','0','0',' ','3','.','3','D',' ','7','1','0','0'};
  if(memcmp(buffer,header_sit,sizeof(header_sit))==0)
    return file_hint_sit.extension;
  return NULL;
}
